@@ -1,24 +1,23 @@
-import numpy as np
-from sklearn.metrics.pairwise import check_pairwise_arrays
+
+
+import torch
+from . import exceptions
 
 
 def uniform_vector(n):
-    return np.ones(n)/n
+    return torch.ones(n)/n
 
 
 def onehot_vector(n,idx):
-	w = np.zeros(n)
+	w = torch.zeros(n)
 	w[idx] = 1
 	return w
 
 
-
-
 def identity_kernel(n):
-    return np.diag(np.ones(n))
+    return torch.diag(torch.ones(n))
+
 
-def to_diagonal(K):
-    return np.diagonal([K[i,i] for i in range(K.shape[0])])
 
 def ideal_kernel(Y, T=None):
     """performs the ideal kernel between the labels vectors *Y* and *Z*.
@@ -38,10 +37,12 @@ def ideal_kernel(Y, T=None):
     K : (l,n) ndarray,
         the ideal kernel matrix.
     """
+    if len(Y.unique()) > 2:
+        raise exceptions.BinaryProblemError('Ideal kernel works only for binary problems')
     pos = Y[0]
-    yy = [1 if y==pos else -1 for y in Y]
-    tt = yy if T is None else [1 if t==pos else -1 for t in T]
-    return np.dot(np.array([yy]).T,np.array([tt]))
+    yy = (Y == pos) * 2 - 1
+    tt = yy if (T is None) or (T is Y) else (T == pos) * 2 - 1
+    return yy.view(len(yy), 1) @ tt.view(1, len(tt))
 
 
 
